@@ -33,9 +33,7 @@ from sge.r import (_scale, _get_blend_flags, _set_mode, _handle_music,
                    _get_dot_sprite, _get_line_sprite, _get_rectangle_sprite,
                    _get_ellipse_sprite, _get_circle_sprite,
                    _get_polygon_sprite, bl_update, bl_get_image, o_update,
-                   o_detect_collisions, o_get_image_width,
-                   o_get_normal_image_width, o_get_image_height,
-                   o_get_normal_image_height, s_get_image)
+                   o_detect_collisions, s_get_image)
 
 
 __all__ = ['Game']
@@ -913,8 +911,12 @@ class Game(object):
         for view in self.current_room.views:
             view_surf = pygame.Surface((view.width, view.height))
             view_surf.fill(pygame.Color(*self.current_room.background.color))
-            vx = view.x - sge.game.current_room.background_x
-            vy = view.y - sge.game.current_room.background_y
+            view_x = view.x
+            view_y = view.y
+            view_width = view.width
+            view_height = view.height
+            vx = view_x - sge.game.current_room.background_x
+            vy = view_y - sge.game.current_room.background_y
 
             images = []
 
@@ -932,14 +934,14 @@ class Game(object):
                 # Move to the best position for what we want to do
                 if layer.repeat_right and (layer.repeat_left or x < 0):
                     x = (x % img_w) - img_w
-                elif layer.repeat_left and x + img_w > view.width:
-                    x = (x % img_w) + img_w * math.ceil(view.width / img_w)
+                elif layer.repeat_left and x + img_w > view_width:
+                    x = (x % img_w) + img_w * math.ceil(view_width / img_w)
                 if layer.repeat_down and (layer.repeat_up or y < 0):
                     y = (y % img_h) - img_h
-                elif layer.repeat_up and y + img_h > view.height:
-                    y = (y % img_h) + img_h * math.ceil(view.height / img_h)
+                elif layer.repeat_up and y + img_h > view_height:
+                    y = (y % img_h) + img_h * math.ceil(view_height / img_h)
 
-                if layer.repeat_right and (layer.repeat_left or x < view.width):
+                if layer.repeat_right and (layer.repeat_left or x < view_width):
                     hrange = six.moves.range(int(x),
                                              int(view.width + img_w), img_w)
                 elif layer.repeat_left and x + img_w > 0:
@@ -947,9 +949,9 @@ class Game(object):
                 else:
                     hrange = [x]
 
-                if layer.repeat_down and (layer.repeat_up or y < view.height):
+                if layer.repeat_down and (layer.repeat_up or y < view_height):
                     vrange = six.moves.range(int(y),
-                                             int(view.height + img_h), img_h)
+                                             int(view_height + img_h), img_h)
                 elif layer.repeat_up and y + img_h > 0:
                     vrange = six.moves.range(int(y), -img_h, -img_h)
                 else:
@@ -957,7 +959,7 @@ class Game(object):
 
                 for y in vrange:
                     for x in hrange:
-                        images.append((img, x + view.x, y + view.y, layer.z,
+                        images.append((img, x + view_x, y + view_y, layer.z,
                                        None))
 
             for obj in self.current_room.objects:
@@ -967,16 +969,20 @@ class Game(object):
                                       obj.image_xscale, obj.image_yscale,
                                       obj.image_rotation, obj.image_alpha,
                                       obj.image_blend)
-                    w = o_get_image_width(obj)
-                    nw = o_get_normal_image_width(obj)
-                    h = o_get_image_height(obj)
-                    nh = o_get_normal_image_height(obj)
-                    xoff = (w - nw) / 2
-                    yoff = (h - nh) / 2
-                    origin_x = obj.image_origin_x + xoff
-                    origin_y = obj.image_origin_y + yoff 
-                    images.append((img, obj.x - origin_x, obj.y - origin_y,
-                                   obj.z, None))
+                    w = img.get_width()
+                    h = img.get_height()
+                    x = obj.x - obj.image_origin_x
+                    y = obj.y - obj.image_origin_y
+                    if (x + w >= view_x and x <= view_x + view_width and
+                            y + h >= view_y and y <= view_y + view_height):
+                        nimg = s_get_image(obj.sprite, obj.image_index,
+                                           obj.image_xscale, obj.image_yscale)
+                        nw = nimg.get_width()
+                        nh = nimg.get_height()
+                        xoff = (w - nw) / 2
+                        yoff = (h - nh) / 2
+                        images.append((img, x - xoff, y - yoff,
+                                       obj.z, None))
 
             images.extend(self.current_room.rd["projections"])
 
