@@ -685,7 +685,7 @@ class Object(object):
                 r.cache.add(i, offset)
                 return self.x - (origin_x + offset)
             else:
-                return self.x - origin_x
+                return self.x - self.image_origin_x
         else:
             return self.bbox_left
 
@@ -710,7 +710,7 @@ class Object(object):
                 r.cache.add(i, offset)
                 return self.y - (origin_y + offset)
             else:
-                return self.y - origin_y
+                return self.y - self.image_origin_y
         else:
             return self.bbox_top
 
