@@ -647,39 +647,19 @@ def o_detect_collisions(self):
             other.event_collision(self, -xdirection, -ydirection)
 
 
-def o_get_image_width(self):
-    # Get the width of the sprite when scaled rotated.
-    return int(s_get_image(self.sprite, self.image_index, self.image_xscale,
-                           self.image_yscale, self.image_rotation).get_width())
-
-
-def o_get_normal_image_width(self):
-    # Get the width of the sprite without rotation.
-    return int(s_get_image(self.sprite, self.image_index, self.image_xscale,
-                           self.image_yscale).get_width())
-
-
-def o_get_image_height(self):
-    # Get the height of the sprite when scaled rotated.
-    return int(s_get_image(self.sprite, self.image_index, self.image_xscale,
-                           self.image_yscale, self.image_rotation).get_height())
-
-
-def o_get_normal_image_height(self):
-    # Get the height of the sprite without rotation.
-    return int(s_get_image(self.sprite, self.image_index, self.image_xscale,
-                           self.image_yscale).get_height())
-
-
 def o_get_origin_offset(self):
     # Return the amount to offset the origin as (x, y).
     new_origin_x = self.sprite.origin_x
     new_origin_y = self.sprite.origin_y
 
-    width = o_get_image_width(self) / abs(self.image_xscale)
-    height = o_get_image_height(self) / abs(self.image_yscale)
-    normal_width = o_get_normal_image_width(self) / abs(self.image_xscale)
-    normal_height = o_get_normal_image_height(self) / abs(self.image_yscale)
+    img = s_get_image(self.sprite, self.image_index, self.image_xscale,
+                      self.image_yscale, self.image_rotation)
+    nimg = s_get_image(self.sprite, self.image_index, self.image_xscale,
+                       self.image_yscale)
+    width = img.get_width() / abs(self.image_xscale)
+    height = img.get_height() / abs(self.image_yscale)
+    normal_width = nimg.get_width() / abs(self.image_xscale)
+    normal_height = nimg.get_height() / abs(self.image_yscale)
 
     if self.image_rotation % 360:
         center_x = normal_width / 2
